"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const constants_1 = require("./constants");
const download_1 = require("./download");
const logging_1 = require("./logging");
const offline_1 = require("./offline");
/**
 * Aquire the installers, either by copying them from
 * their offline location or by downloading them.
 *
 * @param {() => void} cb\
 * @returns {Promise.void}
 */
async function aquireInstallers(cb) {
    const handleFailure = (error) => {
        logging_1.log(chalk_1.default.bold.red(`Downloading installers failed. Error:`), error);
        logging_1.log(chalk_1.default.bold.red(`windows-build-tools will now exit.`));
        process.exit(1);
    };
    if (constants_1.OFFLINE_PATH) {
        try {
            await offline_1.copyInstallers();
            cb();
        }
        catch (error) {
            handleFailure(error);
        }
    }
    else {
        try {
            await download_1.download(cb);
        }
        catch (error) {
            handleFailure(error);
        }
    }
}
exports.aquireInstallers = aquireInstallers;
//# sourceMappingURL=aquire-installers.js.map